@@ -523,7 +523,7 @@ class MlModles:
         Window = 5  # Maximum distance between the current and predicted word within a sentence
 
         # train word2vec model
-        model = Word2Vec(x, size=Size, window=Window, workers=Workers, min_count=Min_count)
+        model = Word2Vec(X_train_tok, size=Size, window=Window, workers=Workers, min_count=Min_count)
         w2v = dict(zip(model.wv.index2word, model.wv.syn0))
         modelw = MeanEmbeddingVectorizer(w2v)
 
@@ -563,7 +563,7 @@ class MlModles:
         Window = 5  # Maximum distance between the current and predicted word within a sentence
 
         # train word2vec model
-        model = Word2Vec(x, size=Size, window=Window, workers=Workers, min_count=Min_count)
+        model = Word2Vec(X_train_tok, size=Size, window=Window, workers=Workers, min_count=Min_count)
         w2v = dict(zip(model.wv.index2word, model.wv.syn0))
         modelw = MeanEmbeddingVectorizer(w2v)
 
@@ -621,7 +621,7 @@ class MlModles:
         model_dict = estimator[model_name_dict[model_name]][1]
         model_accuracy = model_dict.kw_args['active'][1]
         select_model = model_dict.kw_args['active'][0]
-        model_confusion_matrix = funtran.kw_args['active'][3]
+        model_confusion_matrix = model_dict.kw_args['active'][3]
         return select_model, model_accuracy, model_confusion_matrix
 
     def get_model_name_dict(self):
